@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,11 +18,14 @@
 #ifndef VOTCA_TOOLS_CROSSCORRELATE_H
 #define VOTCA_TOOLS_CROSSCORRELATE_H
 
-#include "datacollection.h"
+// Standard includes
 #include <iostream>
 #include <vector>
-#include <votca/tools/eigen.h>
-#include <votca/tools/types.h>
+
+// Local VOTCA includes
+#include "datacollection.h"
+#include "eigen.h"
+#include "types.h"
 
 namespace votca {
 namespace tools {
@@ -54,4 +57,4 @@ inline std::ostream& operator<<(std::ostream& out, const CrossCorrelate& c) {
 }  // namespace tools
 }  // namespace votca
 
-#endif /* VOTCA_TOOLS_CROSSCORRELATE_H */
+#endif  // VOTCA_TOOLS_CROSSCORRELATE_H
