@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@
 #ifndef VOTCA_TOOLS_THREAD_H
 #define VOTCA_TOOLS_THREAD_H
 
+// Standard includes
 #include <pthread.h>
 
 namespace votca {
@@ -71,7 +72,7 @@ class Thread {
   pthread_t _thread;
   bool _finished;
 };
-}
-}
+}  // namespace tools
+}  // namespace votca
 
 #endif  // VOTCA_TOOLS_THREAD_H
