@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,11 +15,8 @@
  *
  */
 
-#include <votca/tools/crosscorrelate.h>
-#include <votca/tools/eigen.h>
-
-// include after eigen.h
-#include <unsupported/Eigen/FFT>
+// Local VOTCA includes
+#include "votca/tools/crosscorrelate.h"
 
 namespace votca {
 namespace tools {
