@@ -1,5 +1,5 @@
 /*
- *            Copyright 2009-2019 The VOTCA Development Team
+ *            Copyright 2009-2020 The VOTCA Development Team
  *                       (http://www.votca.org)
  *
  *      Licensed under the Apache License, Version 2.0 (the "License")
@@ -17,8 +17,11 @@
  *
  */
 
+// Third party includes
 #include <boost/algorithm/string.hpp>
-#include <votca/tools/elements.h>
+
+// Local VOTCA includes
+#include "votca/tools/elements.h"
 
 namespace votca {
 namespace tools {
@@ -166,7 +169,7 @@ bool Elements::isEleShort(std::string shortname) {
 
 bool Elements::isMassAssociatedWithElement(double mass, double tolerance) {
   auto closestMatch = findShortNameOfElementClosestInMass_(mass);
-  if (closestMatch.second / _Mass[closestMatch.first] > tolerance) {
+  if (closestMatch.second > tolerance) {
     return false;
   }
   return true;
@@ -174,7 +177,7 @@ bool Elements::isMassAssociatedWithElement(double mass, double tolerance) {
 
 std::string Elements::getEleShortClosestInMass(double mass, double tolerance) {
   auto closestMatch = findShortNameOfElementClosestInMass_(mass);
-  if (closestMatch.second / _Mass[closestMatch.first] > tolerance) {
+  if (closestMatch.second > tolerance) {
     throw std::runtime_error(
         "In attempt to determine if mass is associated "
         " with an element the mass exceeds tolerance of a possible match");
