@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,11 @@
  *
  */
 
+// Standard includes
 #include <algorithm>
-#include <votca/tools/histogramnew.h>
+
+// Local VOTCA includes
+#include "votca/tools/histogramnew.h"
 
 using namespace std;
 namespace votca {
