@@ -1,5 +1,5 @@
 /*
- *            Copyright 2009-2019 The VOTCA Development Team
+ *            Copyright 2009-2020 The VOTCA Development Team
  *                       (http://www.votca.org)
  *
  *      Licensed under the Apache License, Version 2.0 (the "License")
@@ -17,10 +17,13 @@
  *
  */
 
+// Standard includes
 #include <algorithm>
 #include <cassert>
-#include <votca/tools/edge.h>
-#include <votca/tools/reducedgraph.h>
+
+// Local VOTCA includes
+#include "votca/tools/edge.h"
+#include "votca/tools/reducedgraph.h"
 
 using namespace std;
 
